@@ -10,7 +10,10 @@ from collections import defaultdict, namedtuple
 from functools import partial
 from operator import methodcaller
 
-from mock import Mock
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 from pytest import mark, raises
 
 from schema import (
